@@ -22,17 +22,15 @@ package Locale::Messages;
 
 use strict;
 
-use File::Spec;
-
 use vars qw ($package @EXPORT_OK %EXPORT_TAGS @ISA $VERSION);
 
-$VERSION = '1.30';
+$VERSION = '1.34';
 
 # Try to load the C version first.
 $package = 'gettext_xs';
 
 # Do not load from current working directory.
-local @INC = grep { File::Spec->file_name_is_absolute($_) } @INC;
+local @INC = grep { $_ ne '.' } @INC;
 
 eval <<'EOF';
 require Locale::gettext_xs; 
@@ -1001,8 +999,12 @@ Imports the locale category constants:
 
 =head1 OTHER EXPORTS
 
+=over 4
+
 =item B<select_package PACKAGE>
 
+=back
+
 =head1 USAGE
 
 A complete example:
