@@ -686,6 +686,9 @@ sub set_locale {
 	
 	require POSIX;
 
+    # See https://github.com/gflohr/libintl-perl/issues/14!
+    no warnings 'locale';
+
     $country = '' unless defined $country;
     $charset = '' unless defined $charset;
     
@@ -815,6 +818,9 @@ sub set_locale {
 sub __set_locale_windows {
 	my ($category, $language, $country, $charset) = @_;
 
+    # See https://github.com/gflohr/libintl-perl/issues/14!
+    no warnings 'locale';
+
     my $set_locale;
 
     $country = '' unless defined $country;
@@ -1206,4 +1212,3 @@ cperl-indent-level: 4
 cperl-continued-statement-offset: 2
 tab-width: 4
 End:
-=cut
