@@ -38,6 +38,7 @@ use vars qw ($__gettext_pp_default_dir
 
 use locale;
 use File::Spec;
+use Locale::Messages;
 
 BEGIN {
     $__gettext_pp_textdomain = 'messages';
@@ -752,6 +753,8 @@ sub __locale_category
     my ($category, $category_name) = @_;
     
     local $@;
+    # See https://github.com/gflohr/libintl-perl/issues/14!
+    no warnings 'locale';
     my $value = eval {POSIX::setlocale ($category)};
     
     # We support only XPG syntax, i. e.
@@ -1117,5 +1120,3 @@ perl-brace-imaginary-offset: 0
 perl-label-offset: -4
 tab-width: 4
 End:
-
-=cut
